@@ -5,11 +5,13 @@
 #  values per dataset. When clicking on one attribute name,
 #  the contains of the web help is displayed.
 
-import ab6_invars as abinit
+import ctypes
+ctypes.PyDLL("./ab7_invars.so", mode=ctypes.RTLD_GLOBAL)
+import ab7_invars as abinit
 import numpy
 import pygtk, gtk, gobject
 import re, sys, os
-import ElementTree
+import xml.etree.ElementTree as ElementTree
 
 def delete_event(widget, event, data=None):
     return False
@@ -325,7 +327,10 @@ if __name__ == "__main__":
     gobject.idle_add(withArg, sys.argv, window)
 
   # We parse the variable defs.
-  varlist = ElementTree.parse("varlists.xml").findall("list/variable")
+  try:
+    varlist = ElementTree.parse("varlists.xml").findall("list/variable")
+  except:
+    varlist  =[]
   window.set_data("varlist", varlist)
 
   gtk.main()
