@@ -7,18 +7,18 @@ int main(void)
 #if defined __i386
 #define arch "x86_32"
 #elif defined __ia64
-#define arch "IA64"
+#define arch "ia64"
 #else
-#define arch "UNKNOWN"
+#define arch "unknown"
 #endif
 #if defined __linux__
-#define system "LINUX"
+#define system "linux"
 #elif defined __macosx__
-#define system "MACOSX"
+#define system "macosx"
 #else
-#define system "UNKNOWN"
+#define system "unknown"
 #endif
- printf("GCC %d.%d %s %s\n",__GNUC__,__GNUC_MINOR__,arch,system);
+ printf("gnu %d.%d %s %s\n",__GNUC__,__GNUC_MINOR__,arch,system);
 #endif
 
  return(0);
