@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2012 ABINIT group (MG)
+ * Copyright (C) 2009-2014 ABINIT group (MG)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@ void
 FC_FUNC_(clib_alignment_of,clib_ALIGNMENT_OF)
   (void *p, int *nbytes, int *algn)
 {
-  if (*nbytes)
+  if (*nbytes){
     *algn = (int)(((uintptr_t) p) % *nbytes);
+     /*printf("address = %p; uintptr = %d\n", p, (uintptr_t) p);*/
+  }
   else 
     *algn = 0;
 }
