@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2012 ABINIT group (MG)
+ * Copyright (C) 2009-2014 ABINIT group (MG)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ void
 FC_FUNC_(clib_mtrace, CLIB_MTRACE)
   (int *ierr)
 {
-#if defined CC_GNU
+#ifdef HAVE_MCHECK_H
   mtrace();
   *ierr=0;
 #else
@@ -68,7 +68,7 @@ void
 FC_FUNC_(CLIB_muntrace,CLIB_MUNTRACE) 
   (int* ierr)
 {
-#ifdef CC_GNU
+#ifdef HAVE_MCHECK_H
   muntrace();
   *ierr=0;
 #else
@@ -90,7 +90,7 @@ void
 FC_FUNC_(clib_mcheck,CLIB_MCHECK)
   (int* ierr)
 {
-#ifdef CC_GNU
+#ifdef HAVE_MCHECK_H
   *ierr = mcheck (NULL);
 #else
   *ierr = 2;
