@@ -7,10 +7,12 @@ need_cpp_vars = [
 
 #: List of keywords that are automatically added to all the tests of this suite. 
 keywords = [
+"WVL"
 ]
 
 #: List of input files
 inp_files = [
+"t00.in",
 "t01.in",
 "t02.in",
 "t03.in",
@@ -22,7 +24,6 @@ inp_files = [
 "t10.in",
 "t11.in",
 "t12.in",
-"t13.in",
 "t14.in",
 "t16.in",
 "t17.in",
@@ -30,4 +31,9 @@ inp_files = [
 "t20.in",
 "t21.in",
 "t22.in",
+"t23.in",
+"t31.in",
+"t32.in",
+"t33.in",
+"-t34.in",
 ]
