@@ -7,10 +7,12 @@ need_cpp_vars = [
 
 #: List of keywords that are automatically added to all the tests of this suite. 
 keywords = [
+"ETSF_IO"
 ]
 
 #: List of input files
 inp_files = [
+"t00.in",
 "t01.in",
 "t02.in",
 "t03.in",
