@@ -2,20 +2,24 @@
 
 #: List of CPP variables that should be defined in config.h in order to enable this suite.
 need_cpp_vars = [
+"HAVE_MPI",
 ]
 
 #: List of keywords that are automatically added to all the tests of this suite. 
 keywords = [
 ]
 
-#subsuites = [
+#: This suite contains tests executed with different numbers of MPI processes.
+is_multi_parallel = True
+
+subsuites = [
 #"tgswl", 
-#"dfpt",
-#"gspw",
+"dfpt",
+"gspw",
 #"mbt",
 #"moldyn",
 #"string",
-#]
+]
 
 #: List of input files
 inp_files = [
@@ -23,11 +27,11 @@ inp_files = [
 #"gswvl_02.in",
 #"tdfpt_01.in",
 #"tdfpt_02.in",
-#"tdfpt_03.in",
-#"tdfpt_04.in",
+"tdfpt_03.in",
+"tdfpt_04.in",
 #"tdfpt_03PAW.in,"
 #"tdfpt_04PAW.in",
-#"tgspw_01.in",
+"tgspw_01.in",
 #"tgspw_02.in",
 #"tgspw_03.in",
 #"tgspw_04.in",
