@@ -10,7 +10,7 @@ keywords = [
 
 subsuites = [
 "elast",
-"elphon",
+"eph",
 "ffield",
 "nlo",
 "optic",   
@@ -26,12 +26,12 @@ inp_files = [
 "telast_4.in",
 "telast_5.in",
 "telast_6.in",
-"telphon_1.in",
-"telphon_2.in",
-"telphon_3.in",
-"telphon_4.in",
-"telphon_5.in",
-"telphon_6.in",
+"teph_1.in",
+"teph_2.in",
+"teph_3.in",
+"teph_4.in",
+"teph_5.in",
+"teph_6.in",
 "tffield_1.in",
 "tffield_2.in",
 "tffield_3.in",
@@ -44,7 +44,7 @@ inp_files = [
 "tnlo_3.in",
 "tnlo_4.in",
 "tnlo_5.in",
-"-tnlo_6.in",      # Disabled
+"tnlo_6.in",      
 "tnlo_7.in",
 "tnlo_8.in",
 "tnlo_9.in",
