@@ -13,7 +13,7 @@ subsuites = [
 "base2",
 "base3",
 "base4",
-"baseparal",
+"basepar",
 "bs",
 "gw1",
 "gw2",
@@ -50,8 +50,8 @@ inp_files = [
 "tbase4_6.in",
 "tbase4_7.in",
 "tbase4_8.in",
-"tbaseparal_1.in",
-"tbaseparal_2.in",
+"tbasepar_1.in",
+"tbasepar_2.in",
 "tbs_1.in",
 "tbs_2.in",
 "tbs_3.in",
