@@ -65,7 +65,7 @@ inp_files = [
 "t54.in",
 "t55.in",
 "t56.in",
-"t57.in",
+"-t57.in",  # ACDF is not supported anymore (requires mkmem ==0)
 "t58.in",
 "t59.in",
 "t60.in",
