@@ -19,7 +19,7 @@ inp_files = [
 "t07.in",
 "t08.in",
 "t09.in",
-"t10.in",
+"-t10.in", # ACDF is not supported anymore (requires mkmem ==0)
 "t17.in",
 "t20.in",
 "t21.in",
