@@ -10,6 +10,7 @@ keywords = [
 
 #: List of input files
 inp_files = [
+"t00.in",
 "t01.in",
 "t02.in",
 "t03.in",
@@ -109,7 +110,6 @@ inp_files = [
 "t97.in",
 "t98.in",
 "t99.in", 
-"-t100.in", # Disabled
 "-t101.in", # Transferred to seq
 "-t102.in", # Presently can't be done (so why not removing it?)
 "-t112.in", # Transferred to seq.
