@@ -56,7 +56,7 @@ inp_files = [
 "t45.in",
 "t46.in",
 "t47.in",
-"t48.in",
+#"t48.in",
 "t49.in",
 "t50.in", 
 "t51.in", 
@@ -97,6 +97,8 @@ inp_files = [
 "t92.in",
 "t93.in",
 "t94.in",
+"-t95.in",   # TOOOO SLOW and not portable (to be debugged)
+"-t96.in",   # TOOOO SLOW and not portable (to be debugged)
 "-t121.in",  # Transfered to seq  
 "-t122.in",  # Transfered to seq 
 "-t123.in",  # Transfered to seq 
